=======
Credits
=======

Development Lead
----------------

* Jeff Kehler <jeffrey.kehler@gmail.com>

Contributors
------------

* `Nathan Lex`_ - Contributed the algorithm for decoding adf.ly links without having to use PyV8 Javascript engine.

.. _`Nathan Lex`: https://github.com/Higgs1